@@ -35,19 +35,14 @@
 #ifndef __spin_H__
 #define __spin_H__
 
+#include "cell.h"
 #include "mathfunc.h"
 #include "symmetry.h"
-#include "cell.h"
 
-Symmetry * spn_get_operations_with_site_tensors(int equiv_atoms[],
-                                                double prim_lattice[3][3],
-                                                int *spin_flips,
-                                                const Symmetry *sym_nonspin,
-                                                const Cell *cell,
-                                                const double *tensors,
-                                                const int tensor_rank,
-                                                const int is_magnetic,
-                                                const double symprec,
-                                                const double angle_tolerance);
+Symmetry *spn_get_operations_with_site_tensors(
+    int equiv_atoms[], double prim_lattice[3][3], int *spin_flips,
+    const Symmetry *sym_nonspin, const Cell *cell, const double *tensors,
+    const int tensor_rank, const int is_magnetic, const double symprec,
+    const double angle_tolerance);
 
 #endif
