@@ -39,30 +39,26 @@
 #include "mathfunc.h"
 
 typedef struct {
-  int size;
-  int (*rot)[3][3];
-  double (*trans)[3];
+    int size;
+    int (*rot)[3][3];
+    double (*trans)[3];
 } Symmetry;
 
 typedef struct {
-  int rot[48][3][3];
-  int size;
+    int rot[48][3][3];
+    int size;
 } PointSymmetry;
 
-Symmetry * sym_alloc_symmetry(const int size);
-void sym_free_symmetry(Symmetry * symmetry);
-Symmetry * sym_get_operation(const Cell * primitive,
-                             const double symprec,
-                             const double angle_tolerance);
-Symmetry * sym_reduce_operation(const Cell * primitive,
-                                const Symmetry * symmetry,
-                                const double symprec,
-                                const double angle_tolerance);
-VecDBL * sym_get_pure_translation(const Cell *cell,
-                                  const double symprec);
-VecDBL * sym_reduce_pure_translation(const Cell * cell,
-                                     const VecDBL * pure_trans,
-                                     const double symprec,
-                                     const double angle_tolerance);
+Symmetry *sym_alloc_symmetry(const int size);
+void sym_free_symmetry(Symmetry *symmetry);
+Symmetry *sym_get_operation(const Cell *primitive, const double symprec,
+                            const double angle_tolerance);
+Symmetry *sym_reduce_operation(const Cell *primitive, const Symmetry *symmetry,
+                               const double symprec,
+                               const double angle_tolerance);
+VecDBL *sym_get_pure_translation(const Cell *cell, const double symprec);
+VecDBL *sym_reduce_pure_translation(const Cell *cell, const VecDBL *pure_trans,
+                                    const double symprec,
+                                    const double angle_tolerance);
 
 #endif
